import request from '@/config/axios'

// 排队 VO
export interface queueVO {
  id: number // id
  patId: string // 患者编号
  patName: string // 患者姓名
  patGender: number // 患者性别
  bookTimeslot: number // 预约时间段
  bookCheckType: number // 预约检查类型
  seqNum: number // 排队序号
  status: number // 10:排队中 20:候诊准备 30:就诊中 40:就诊完成 50:过号 60:过期
  passed: boolean // 过号标记
  expired: boolean // 预约过期标记
  roomId: number // 诊室编号
  roomName: string // 诊室名称
  bedNo: string // 诊疗床编号
}

// 排队 API
export const queueApi = {
  // 查询排队分页
  getqueuePage: async (params: any) => {
    return await request.get({ url: `/ecg/queue/page`, params })
  },

  // 查询排队详情
  getqueue: async (id: number) => {
    return await request.get({ url: `/ecg/queue/get?id=` + id })
  },

  // 新增排队
  createqueue: async (data: queueVO) => {
    return await request.post({ url: `/ecg/queue/create`, data })
  },

  // 修改排队
  updatequeue: async (data: queueVO) => {
    return await request.put({ url: `/ecg/queue/update`, data })
  },

  // 删除排队
  deletequeue: async (id: number) => {
    return await request.delete({ url: `/ecg/queue/delete?id=` + id })
  },

  // 导出排队 Excel
  exportqueue: async (params) => {
    return await request.download({ url: `/ecg/queue/export-excel`, params })
  },

  // 初始化队列信息，用于开诊设置
  openingSetting: async () => {
    return await request.get({ url: `/ecg/queue/opening-setting` })
  }
}
